@@ -8,6 +8,8 @@
 #include <linux/blkdev.h>
 #include "printdev.h"
 
+#include "flags_blkdev.h"
+
 addr_t print_request_queue();
 addr_t print_request();
 
@@ -70,12 +72,15 @@ print_request_queue(addr, full)
 		(p = getsymstr_func((addr_t)rq.merge_bvec_fn))? p: "");
 	mprintf("queuedata:         " FPTR "\n", rq.queuedata);
 
+#ifdef _request_queue_has_plug_list
 	mprintf("plug_list:         ");
 	if ((addr_t)rq.plug_list.next == addr + OFFSET(struct request_queue, plug_list))
 		mprintf(SPTR "  " SPTR "\n", "-", "-");
 	else
 		mprintf(FPTR "  " FPTR "\n",
 			rq.plug_list.next, rq.plug_list.prev);
+#endif
+
 	mprintf("queue_flags:       %lx\n", rq.queue_flags);
 	mprintf("queue_lock:        " FPTR "  %s\n", rq.queue_lock,
 		(p = getsymstr((addr_t)rq.queue_lock))? p: "");
