@@ -19,7 +19,11 @@ mprint_kobject(ko)
 	struct kobject *ko;
 {
 	mprintf("%3x " FPTR " " FPTR " " FPTR " " FPTR " ",
+#if SUBLEVEL>=9
+		ATOMIC_READ(ko->kref.refcount),
+#else
 		ATOMIC_READ(ko->refcount),
+#endif
 		ko->parent, ko->kset, ko->ktype, ko->dentry);
 	mprintstr(ko->name, sizeof(ko->name));
 	mprintf("\n");
