@@ -47,7 +47,6 @@ print_zone(addr, full)
 	mprintf("free_pages         %lx\n", zone.free_pages);
 	mprintf("pages_min/low/high %lx/%lx/%lx\n",
 		zone.pages_min, zone.pages_low, zone.pages_high);
-	mprintf("refill_counter     %x\n", ATOMIC_READ(zone.refill_counter));
 	mprintf("nr_active          %lx\n", zone.nr_active);
 	mprintf("nr_inactive        %lx\n", zone.nr_inactive);
 	mprintf("all_unreclaimable  %x\n", zone.all_unreclaimable);
@@ -136,7 +135,6 @@ print_pglist_data(addr)
 	}
 	mprintf("nr_zones           %x\n", pg.nr_zones);
 	mprintf("node_mem_map       " FPTR "\n", pg.node_mem_map);
-	mprintf("valid_addr_bitmap  " FPTR "\n", pg.valid_addr_bitmap);
 	mprintf("bdata              " FPTR "\n", pg.bdata);
 	mprintf("node_start_pfn     %lx\n", pg.node_start_pfn);
 	mprintf("node_present_pages %lx / %lx\n",
