@@ -175,7 +175,7 @@ print_task(addr, full)
 	mprintf("\tksp:%lx  flags:%lx\n", ts.thread.ksp, ts.thread.flags);
 	mprintf("\tmap_base:%lx  task_size:%lx\n", ts.thread.map_base, ts.thread.task_size);
 #endif /*ARCH_ia64*/
-#if defined(ARCH_ppc)
+#if defined(ARCH_ppc) || defined(ARCH_ppc64)
 	mprintf("\tksp:%lx\n", ts.thread.ksp);
 #endif /*ARCH_ppc*/
 	mprintf("\n");
@@ -199,7 +199,7 @@ getinfo_fromtask(addr, ip, sp, stack)
 	if (sp)
 		*sp = tsk.thread.esp;
 #else
-#if defined(ARCH_ia64) || defined(ARCH_ppc)
+#if defined(ARCH_ia64) || defined(ARCH_ppc) || defined(ARCH_ppc64)
 	if (ip)
 		*ip = 0;
 	if (sp)
