@@ -39,8 +39,11 @@ PRIVATE const char *file_op[] = {
 	"open", "flush", "release", "fsync", "aio_fsync", "fasync", "lock",
 	"readv", "writev",
 	"sendfile", "sendpage", "get_unmapped_area",
-#if _file_operations_has_fcntl
+#ifdef _file_operations_has_fcntl
 	"fcntl",
+#endif
+#ifdef _file_operations_has_check_flags
+	"check_flags", "dir_notify",
 #endif
 	NULL
 };
@@ -49,6 +52,9 @@ PRIVATE const char *inode_op[] = {
 	"INODE OPERATIONS",
 	"create", "lookup", "link", "unlink", "symlink",
 	"mkdir", "rmdir", "mknod", "rename", "readlink", "follow_link",
+#ifdef _file_operation_has_fcntl
+	"put_link",
+#endif
 	"truncate", "permission", "setattr", "getattr",
 	"setxattr", "getxattr", "listxattr", "removexattr",
 	NULL
