@@ -221,7 +221,8 @@ trace()
 		}
 
 		memread(retad, sizeof(funchead), funchead, sym->name);
-		if (funchead[0] == 0xe9 && (strcmp(sym->name, "stext_lock") == 0 || strncmp(sym->name, "_text_lock_", 11) == 0)) {
+		if ((funchead[0] == 0xe9 || (ISPOP(funchead[0]) && (funchead[1] == 0xe9 || ISPOP(funchead[1]) && funchead[2] == 0xe9))) &&
+		    (strcmp(sym->name, "stext_lock") == 0 || strncmp(sym->name, "_text_lock_", 11) == 0 || strncmp(sym->name, ".text.lock.", 11) == 0)) {
 			mprintf(")\n[%8lx] %8lx  [%s]\n", esp, retad, getsymstr(retad));
 			retad += *(unsigned int *)&funchead[1];
 			sym = searchsym_byaddr(retad);
