@@ -10,10 +10,6 @@
 #include <unistd.h>
 #include <netinet/in.h>
 
-#ifdef CONF_USE_LKCD
-#include <kl_error.h>
-#endif /*CONF_USE_LKCD*/
-
 #include "crash.h"
 
 PRIVATE addr_t dsymbol();
@@ -69,6 +65,9 @@ init_mem()
 			fprintf(stderr, "abort\n");
 			exit(1);
 		}
+#if 0
+		kl_init_kern_info();
+#endif
 		printf("\n");
 		return;
 #endif /*CONF_USE_LKCD*/
@@ -91,7 +90,7 @@ ll_memread(addr, size, buf, errmsg)
 	const char *errmsg;
 {
 	if (lseek(mem, (off_t)addr, SEEK_SET) != (off_t)addr) {
-		THROWF("Error: seek to %lx", addr);
+		THROWF2("Error: seek %d to %lx", mem, addr);
 	}
 	(void)memset(buf, '\0', size);
 	if (read(mem, buf, (size_t)size) != (size_t)size) {
@@ -120,7 +119,8 @@ memread(addr, size, buf, errmsg)
 		} while (size);
 #else /*CONF_USE_LKCD*/
 		if (get_block(addr, (unsigned)size, buf, 0)) {
-			THROWF("error %lx", KL_ERROR);
+			kl_print_error();
+			THROWF2("Error: address %lx for %s", addr, errmsg);
 		}
 #endif /*CONF_USE_LKCD*/
 		return;
@@ -248,10 +248,12 @@ init_sym()
 	kmem_low = symtable[0].addr & ~0x0ffffffful;
 	kmem_high = symtable[nsym - 1].addr;
 
+#ifndef CONF_USE_LKCD
 	/* for default V-P transfer */
 	if (physname) {
 		load_pgd(swapper_pg_dir);
 	}
+#endif /*CONF_USE_LKCD*/
 
 	/* get module name list */
 	for (i = 0; i < nsym; i++) {
